@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -224,11 +224,19 @@ void ArticleViewerWebEngine::slotWebHitFinished(const WebEngineViewer::WebHitTes
     }
 
     QMenu popup(this);
-    const bool contentSelected = !selectedText().isEmpty();
-    if (!contentSelected) {
+    const bool noContentSelected = selectedText().isEmpty();
+    if (noContentSelected) {
         if (!mCurrentUrl.isEmpty()) {
-            popup.addAction(createOpenLinkInNewTabAction(mCurrentUrl, this, SLOT(slotOpenLinkInForegroundTab()), &popup));
-            popup.addAction(createOpenLinkInExternalBrowserAction(mCurrentUrl, this, SLOT(slotOpenLinkInBrowser()), &popup));
+            {
+                QAction *act = createOpenLinkInNewTabAction(mCurrentUrl, &popup);
+                connect(act, &QAction::triggered, this, &ArticleViewerWebEngine::slotOpenLinkInBackgroundTab);
+                popup.addAction(act);
+            }
+            {
+                QAction *act = createOpenLinkInExternalBrowserAction(mCurrentUrl, &popup);
+                connect(act, &QAction::triggered, this, &ArticleViewerWebEngine::slotOpenLinkInBrowser);
+                popup.addAction(act);
+            }
             popup.addSeparator();
             popup.addAction(mActionCollection->action(QStringLiteral("savelinkas")));
             popup.addAction(mActionCollection->action(QStringLiteral("copylinkaddress")));
